## $Id: utils.py 17952 2024-11-05 11:51:11Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""General helper functions and utilities for the application section.
"""

from kofacustom.nigeria.applicants.utils import NigeriaApplicantsUtils
from waeup.kofa.applicants.workflow import (INITIALIZED,
    STARTED, PAID, ADMITTED, NOT_ADMITTED, SUBMITTED, CREATED)
from kofacustom.unidel.interfaces import MessageFactory as _



class ApplicantsUtils(NigeriaApplicantsUtils):
    """A collection of parameters and methods subject to customization.
    """

    APP_TYPES_DICT = {
        'app': ['General Studies', 'APP'],
        'ase': ['Admission Screening Exercise', 'ASE'], # successor of putme
        'ugpt': ['Undergraduate Part-Time Programmes', 'PT'],
        'jupeb': ['JUPEB Pre-Degree (Foundation) Programmes', 'PRE'],
        'ijmb': ['IJMB Foundation School Programmes', 'IJMB'],
        'pre': ['Pre-Degree (Foundation) Studies', 'PRE'],
        'dpft': ['Diploma Programmes Full-Time Programmes', 'DP'],
        'dppt': ['Diploma Programmes Part-Time Programmes', 'DP'],
        'de': ['Direct Entry Programmes', 'DEP'],
        'df': ['Digital Forensic for Professionals and Academia', 'DF'],
        'law': ['Certificate in Law Programme', 'CL'],
        'pde': ['Professional Diploma in Education Programmes', 'PDE'],
        'trcdeg': ['TRCN Degree Programmes', 'TRCD'],
        'trcnce': ['TRCN NCE Programmes', 'TRCN'],
        }

    SEPARATORS_DICT = {
        'form.applicant_id': _(u'Base Data'),
        'form.course1': _(u'Programmes/Courses Desired'),
        'form.hq_type': _(u'Higher Education Record'),
        'form.presently': _(u'Course or Programme Presently Attending'),
        'form.nysc_year': _(u'NYSC Information'),
        'form.employer': _(u'Employment History'),
        'form.jamb_reg_number': _(u'JAMB Data'),
        #'form.jamb_subjects': _(u'JAMB Data'),
        #'form.jamb_subjects_list': _(u'JAMB Data'),
        'form.notice': _(u'Application Process Information'),
        'form.pp_school': _(u'Post Primary School Qualification'),
        'form.presently_inst': _(u'Presently attending a course or programme'),
        'form.fst_sit_fname': _(u'First Sitting Record'),
        'form.scd_sit_fname': _(u'Second Sitting Record'),
        'form.referees': _(u'Referees'),
        }